<?php
/**
 * Plugin Name: LiveClock
 * Plugin URI: https://www.inzinc.com
 * Description: A dynamic clock and date display plugin with customization options
 * Version: 1.0.0
 * Author: Desmond J. Coates
 * Author URI: https://www.inzinc.com
 * Text Domain: liveclock
 * License: GPL v2 or later
 */

declare(strict_types=1);

if (!defined('ABSPATH')) {
    exit;
}

class LiveClock {
    private static $instance = null;

    public static function getInstance() {
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function __construct() {
        add_action('admin_menu', [$this, 'addAdminMenu']);
        add_action('admin_init', [$this, 'registerSettings']);
        add_action('wp_enqueue_scripts', [$this, 'enqueueScripts']);
        add_shortcode('live_clock', [$this, 'renderClock']);
        add_action('admin_enqueue_scripts', [$this, 'enqueueAdminScripts']);
    }

    public function addAdminMenu() {
        add_menu_page(
            'LiveClock Settings',
            'LiveClock',
            'manage_options',
            'liveclock-settings',
            [$this, 'renderSettingsPage'],
            'dashicons-clock'
        );
    }

    public function registerSettings() {
        register_setting('liveclock_options', 'liveclock_settings');
        
        add_settings_section(
            'liveclock_main',
            'Display Settings',
            null,
            'liveclock-settings'
        );

        $fields = [
            'time_format' => 'Time Format',
            'date_format' => 'Date Format',
            'font_size' => 'Font Size (px)',
            'font_family' => 'Font Family',
            'text_color' => 'Text Color',
            'orientation' => 'Display Orientation'
        ];

        foreach ($fields as $field => $label) {
            add_settings_field(
                'liveclock_' . $field,
                $label,
                [$this, 'renderField'],
                'liveclock-settings',
                'liveclock_main',
                ['field' => $field]
            );
        }
    }

    public function renderField($args) {
        $options = get_option('liveclock_settings', []);
        $field = $args['field'];
        $value = $options[$field] ?? '';

        switch ($field) {
            case 'orientation':
                echo '<select name="liveclock_settings[' . $field . ']">';
                echo '<option value="vertical" ' . selected($value, 'vertical', false) . '>Vertical</option>';
                echo '<option value="horizontal" ' . selected($value, 'horizontal', false) . '>Horizontal</option>';
                echo '</select>';
                break;
            case 'text_color':
                echo '<input type="color" name="liveclock_settings[' . $field . ']" value="' . esc_attr($value) . '">';
                break;
            default:
                echo '<input type="text" name="liveclock_settings[' . $field . ']" value="' . esc_attr($value) . '">';
        }
    }

    public function renderSettingsPage() {
        if (!current_user_can('manage_options')) {
            return;
        }
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <div class="notice notice-info">
                <p>Use shortcode <code>[live_clock]</code> to display the clock in your posts or pages.</p>
            </div>
            <form action="options.php" method="post">
                <?php
                settings_fields('liveclock_options');
                do_settings_sections('liveclock-settings');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }

    public function enqueueScripts() {
        wp_enqueue_style(
            'liveclock-style',
            plugins_url('css/liveclock.css', __FILE__),
            [],
            '1.0.0'
        );

        wp_enqueue_script(
            'liveclock-script',
            plugins_url('js/liveclock.js', __FILE__),
            [],
            '1.0.0',
            true
        );

        wp_localize_script('liveclock-script', 'liveclockSettings', [
            'options' => get_option('liveclock_settings', [])
        ]);
    }

    public function enqueueAdminScripts($hook) {
        if ($hook !== 'toplevel_page_liveclock-settings') {
            return;
        }

        wp_enqueue_style('liveclock-admin', plugins_url('css/admin.css', __FILE__));
    }

    public function renderClock($atts) {
        $options = get_option('liveclock_settings', []);
        $orientation = $options['orientation'] ?? 'vertical';
        
        ob_start();
        ?>
        <div class="liveclock-container <?php echo esc_attr($orientation); ?>">
            <div class="liveclock-time"></div>
            <div class="liveclock-date"></div>
        </div>
        <?php
        return ob_get_clean();
    }
}

// Initialize the plugin
LiveClock::getInstance();
